import { BigNumberish, ContractTransaction, ethers, Signer } from "ethers";
import { ActionsStorageV10 } from "./types";
import { DecodedCall } from "./abiDecoderController";
export declare class ActionsStorageController {
    private _actionsStorageAddress;
    private _signer;
    private _actionsStorageContract?;
    constructor(actionsStorageAddress: string, signerOrProvider: Signer | ethers.providers.ExternalProvider);
    private _getActionsStorageContract;
    /** Getters */
    getContract(): Promise<ActionsStorageV10>;
    getEntriesByCompany(companyAddress: string): Promise<Array<BigNumberish>>;
    getEntriesByUser(userAddress: string): Promise<Array<BigNumberish>>;
    getEntryData(entryNumber: BigNumberish): Promise<[
        number,
        string,
        string,
        BigNumberish[],
        BigNumberish,
        BigNumberish,
        string[],
        boolean,
        boolean,
        BigNumberish,
        BigNumberish
    ]>;
    getNumOfValidations(entryNumber: BigNumberish): Promise<BigNumberish>;
    getValidation(entryNumber: BigNumberish, position: BigNumberish): Promise<[string, string, BigNumberish]>;
    userHasValidated(userAddress: string, entryNumber: BigNumberish): Promise<boolean>;
    userCanValidate(entryNumber: BigNumberish): Promise<boolean>;
    indexOf(allowedCompanies: Array<string>, companyAddress: string): Promise<BigNumberish>;
    /** Overriden in V1_1 */
    isCompanyOwner(companyAddress: string, assetId: BigNumberish): Promise<boolean>;
    getResourceActionsContract(): Promise<string>;
    /** Overriden in V1_1 */
    getERC721Contract(): Promise<string>;
    getCompaniesContract(): Promise<string>;
    /**Setters */
    setResourceActionsContract(newAddress: string): Promise<ContractTransaction>;
    /** Overriden in V1_1 */
    setERC721(newAddress: string): Promise<ContractTransaction>;
    approveProduce(entryNumber: BigNumberish): Promise<ContractTransaction>;
    produce(assetsIds: Array<BigNumberish>): Promise<ContractTransaction>;
    measure(assetsIds: Array<BigNumberish>, requiredSignatures: BigNumberish, companiesInvolved: Array<string>): Promise<ContractTransaction>;
    pickUp(assetsIds: Array<BigNumberish>, requiredSignatures: BigNumberish, companiesInvolved: Array<string>): Promise<ContractTransaction>;
    dropOff(assetsIds: Array<BigNumberish>, requiredSignatures: BigNumberish, companiesInvolved: Array<string>, outputOf: BigNumberish): Promise<ContractTransaction>;
    validateEntry(entryNumber: BigNumberish): Promise<ContractTransaction>;
    /** Helpers */
    static encodeCall(functionName: string, args?: any[]): string;
    static decodeCall(data: string): DecodedCall | null;
}
