import { BigNumberish, ContractTransaction, ethers, Signer } from "ethers";
import { ERC721BeefLedgerV10 } from "./types";
import { ERC721BeefLedgerV11 } from "./types/ERC721BeefLedgerV11";
import { DecodedCall } from "./abiDecoderController";
export declare class ERC721Controller {
    private _signer;
    private _erc721Address;
    private _erc721Contract?;
    constructor(erc721Address: string, signerOrProvider: Signer | ethers.providers.ExternalProvider);
    static deployERC721Contract(signer: Signer, multisigAddress: string): Promise<[ERC721BeefLedgerV10, string]>;
    upgradeERC721ContractV11(signer: Signer, proxyAddress: string): Promise<ERC721BeefLedgerV11>;
    private _getERC721Contract;
    /** Getters */
    getContract(): Promise<ERC721BeefLedgerV11>;
    balanceOf(user: string): Promise<BigNumberish>;
    getApproved(tokenId: BigNumberish): Promise<string>;
    isApprovedForAll(owner: string, operator: string): Promise<boolean>;
    exists(tokenId: BigNumberish): Promise<boolean>;
    getTotalTokens(): Promise<BigNumberish>;
    getOwnerOf(tokenId: BigNumberish): Promise<string>;
    getOwner(): Promise<string>;
    /** Version 1_1 */
    getGroupingAddress(tokenId: BigNumberish): Promise<string>;
    /**Setters */
    setMultisigWallet(newAddress: string): Promise<ContractTransaction>;
    approve(to: string, tokenId: BigNumberish): Promise<ContractTransaction>;
    setApprovalForAll(to: string, approved: boolean): Promise<ContractTransaction>;
    transferFrom(from: string, to: string, tokenId: BigNumberish): Promise<ContractTransaction>;
    mint(to: string, tokenIds: Array<BigNumberish>): Promise<ContractTransaction>;
    burn(tokenId: BigNumberish): Promise<ContractTransaction>;
    /** Version 1_1 */
    addAssetsToGrouping(tokenIds: Array<BigNumberish>, groupingAddress: string): Promise<ContractTransaction>;
    /** Helpers */
    static encodeCall(functionName: string, args?: any[]): string;
    static decodeCall(data: string): DecodedCall | null;
}
